;Comment the following line to build without runtimes
!define FullInstaller

OutFile "Setup.exe"

; ------------ Global defines ---------------
!define myApp "My App Name"
!define AppVer  "0.1"
!define STANDARD_VERSION "0.1.0.0" ; Must be in x.x.x.x format
!define AppMainExe "MyApp.exe"

!define GTK_INSTALLER_EXE "gtk2-runtime-2.22.0-2010-10-01-ash.exe"
!define GTK_INSTALLER_URL "http://citylan.dl.sourceforge.net/project/gtk-win/GTK%2B%20Runtime%20Environment/GTK%2B%202.22/${GTK_INSTALLER_EXE}"
!define GTK_VER "2.22.0" ;Version of above file

!define GTK_LEAST_MAJOR_VERSION_NEEDED 2
!define GTK_LEAST_MINOR_VERSION_NEEDED 16

!define myComapny "AMIB"
!define /date CurYear "%Y"
; -------------------------------------------

SetCompressor /SOLID lzma
SetCompressorDictSize 8

InstallDir "$PROGRAMFILES\${myApp}"

InstallDirRegKey HKLM "SOFTWARE\${myApp}" "InstallationDirectory"

  !include "MUI2.nsh"
  !define MUI_ABORTWARNING
  !define MUI_COMPONENTSPAGE_SMALLDESC

  RequestExecutionLevel highest

  !insertmacro MUI_PAGE_WELCOME
  !insertmacro MUI_PAGE_LICENSE "Copying.txt"
  !insertmacro MUI_PAGE_COMPONENTS
  Page custom GTKInstType
  !insertmacro MUI_PAGE_DIRECTORY
  !insertmacro MUI_PAGE_INSTFILES
  !insertmacro MUI_PAGE_FINISH

  !insertmacro MUI_UNPAGE_WELCOME
  !insertmacro MUI_UNPAGE_CONFIRM
  !insertmacro MUI_UNPAGE_INSTFILES
  !insertmacro MUI_UNPAGE_FINISH

  !insertmacro MUI_LANGUAGE "English"

; ------------ Version information ----------------
VIProductVersion "${STANDARD_VERSION}"
VIAddVersionKey /LANG=1033 "FileVersion" "${AppVer}"
VIAddVersionKey /LANG=1033 "ProductVersion" "${AppVer}"
VIAddVersionKey /LANG=1033 "ProductName" "${myApp}"
VIAddVersionKey /LANG=1033 "Comments" "${myApp}"
VIAddVersionKey /LANG=1033 "CompanyName" "${myComapny}"
VIAddVersionKey /LANG=1033 "LegalTrademarks" "Copyright  ${CurYear} ${myComapny}"
VIAddVersionKey /LANG=1033 "LegalCopyright" "Copyright  ${myComapny}"
VIAddVersionKey /LANG=1033 "FileDescription" "${myApp} ${AppVer} Setup"
VIAddVersionKey /LANG=1033 "SpecialBuild" "${myApp} Setup, built on ${__TIMESTAMP__}"

Name "${MyApp} ${AppVer} Installer"
Caption "${MyApp} Setup"

Var DIALOG
Var Label
Var Radio1
Var Radio2
Var SelectedOption

SectionGroup /e "${MyApp}" GRP_MAIN

        Section "!Main Programs" SEC_MAIN
                SectionIn RO ;Prevent user unselecting this section
                
                ; ---------- Registry tweaks ---------------
                WriteRegStr HKLM "SOFTWARE\Microsoft\Windows\CurrentVersion\App Paths\${AppMainExe}" "" "$INSTDIR\${AppMainExe}"
                WriteRegStr HKLM "SOFTWARE\Microsoft\Windows\CurrentVersion\App Paths\${AppMainExe}" "Path" "$INSTDIR"
                
                WriteRegStr HKLM "SOFTWARE\${myApp}" "InstallationDirectory" "$INSTDIR"

                ; ---------- Files are copied here ----------
                SetOutPath $INSTDIR
                File "${AppMainExe}"
                
                ; ---------- Create Uninstaller -------------
                WriteUninstaller "$INSTDIR\UnInst.exe"
                WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${myApp}"\
                "UninstallString" "$INSTDIR\UnInst.exe"
                WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${myApp}"\
                "DisplayName" "${myApp}"
                
                ; ---------- Create default shortcuts -------
                CreateDirectory "$STARTMENU\Programs\${myApp}"
                CreateShortCut "$STARTMENU\Programs\${myApp}\${myApp}.lnk" \
                "$INSTDIR\${AppMainExe}"
                CreateShortCut "$STARTMENU\Programs\${myApp}\Uninstall ${myApp}.lnk" \
                "$INSTDIR\UnInst.exe"
                
        SectionEnd

        Section "Desktop Shortcut" SEC_DESKTOP_SHORTCUT
                CreateShortCut "$DESKTOP\${myApp}.lnk" \
                "$INSTDIR\${AppMainExe}"
        SectionEnd

SectionGroupEnd

!ifdef FullInstaller

SectionGroup /e "Runtime files" GRP_RUNTIMES

        Section /o "Download and Install GTK+ for Windows" SEC_GTK_RUNTIME

        TryAgain:
                CreateDirectory "$INSTDIR\Redist"
                NSISdl::download "${GTK_INSTALLER_URL}" "$INSTDIR\Redist\${GTK_INSTALLER_EXE}"
                Pop $R0
                StrCmp $R0 "success" +3
                MessageBox MB_ICONQUESTION|MB_YESNO "Setup was unable to download files completely.$\nDo you wish to try again?" IDYES TryAgain IDNO NoGTK

                DetailPrint "Installing GTK+ for Windows..."
                SetDetailsPrint none

                IntCmp $SelectedOption 2 Local Global Global

        Local:
                ; Local installation
              	ExecWait '"$INSTDIR\Redist\${GTK_INSTALLER_EXE}" /sideeffects=no /dllpath=root /translations=no /compatdlls=no /S /D=$INSTDIR'
              	Goto Done
              	
        Global:
                ; Global installation
              	ExecWait '"$INSTDIR\Redist\${GTK_INSTALLER_EXE}"'

        Done:
                SetDetailsPrint both
                Delete "$INSTDIR\Redist\${GTK_INSTALLER_EXE}"

        NoGTK:
               	RMDir "$INSTDIR\Redist"

        SectionEnd

SectionGroupEnd

!endif

Section "Uninstall"
        SetShellVarContext current
        Delete "$INSTDIR\UnInst.exe"
        Delete "$INSTDIR\${AppMainExe}"
        
        ; Uninstall local GTK+
        ExecWait "$INSTDIR\gtk2_runtime_uninst.exe /remove_config=yes /sideeffects=no /dllpath=root /translations=no /compatdlls=no /S"
        RMDir "$INSTDIR\share\local"
        RMDir "$INSTDIR\share"
        
        RMDir "$INSTDIR"

        Delete "$DESKTOP\${myApp}.lnk"
        RMdir /r "$STARTMENU\Programs\${myApp}"

        DeleteregKey HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${myApp}"
        DeleteregKey HKLM "Software\${myApp}"
        
SectionEnd

var SEC_GTK_RUNTIME_Description

Function .onInit

        SectionSetSize ${SEC_GTK_RUNTIME} 14400

        !ifdef FullInstaller

            GetDllVersion "libgtk-win32-2.0-0.dll" $R0 $R1
            IntOp $R2 $R0 / 0x00010000
            IntOp $R3 $R0 & 0x0000FFFF
            IntOp $R4 $R1 / 0x00010000
            IntOp $R5 $R1 & 0x0000FFFF
            StrCpy $0 "$R2.$R3.$R4.$R5"
            
            IntCmp $R2 ${GTK_LEAST_MAJOR_VERSION_NEEDED} 0 Old VerOK
            IntCmp $R3 ${GTK_LEAST_MINOR_VERSION_NEEDED} VerOK Old VerOK

            Old:
              IntOp $0 ${SF_SELECTED} | ${SF_RO}
              SectionSetFlags ${SEC_GTK_RUNTIME} $0
              
              StrCpy $SEC_GTK_RUNTIME_Description "It is required to download and install GTK2-Runtime v${GTK_VER}"
              Goto Exit

            VerOk:
              StrCpy $SEC_GTK_RUNTIME_Description "Found GTK2-Runtime installed on your system"

            Exit:

        !endif
FunctionEnd

!insertmacro MUI_FUNCTION_DESCRIPTION_BEGIN
  !insertmacro MUI_DESCRIPTION_TEXT ${GRP_MAIN} "${myApp}"
  !insertmacro MUI_DESCRIPTION_TEXT ${SEC_MAIN} "${myApp} exectuable and start menu shortcuts"
  !insertmacro MUI_DESCRIPTION_TEXT ${SEC_DESKTOP_SHORTCUT} "Optional desktop shortcut"

!ifdef FullInstaller
  !insertmacro MUI_DESCRIPTION_TEXT ${GRP_RUNTIMES} "Runtimes that may be required on some OSs"
  !insertmacro MUI_DESCRIPTION_TEXT ${SEC_GTK_RUNTIME} $SEC_GTK_RUNTIME_Description
!endif

!insertmacro MUI_FUNCTION_DESCRIPTION_END

!include "CustomPage.nsh"